@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: BaseFont.pm,v 2.0 2005/11/16 02:16:04 areibens Exp $
+#   $Id: BaseFont.pm,v 2.2 2006/06/14 16:57:52 areibens Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::BaseFont;
@@ -46,7 +46,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource );
 
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.0 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/11/16 02:16:04 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.2 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2006/06/14 16:57:52 $
 
 }
 no warnings qw[ deprecated recursion uninitialized ];
@@ -169,7 +169,7 @@ sub tounicodemap {
         $cmap.=qq|1 begincodespacerange\n<00> <FF>\nendcodespacerange\n|;
         $cmap.=qq|256 beginbfchar\n|; 
         for(my $j=0; $j<256;$j++) {
-            $cmap.=sprintf(qq|<%02X> <%04X>\n|,$j,$self->uniByMap($j));
+            $cmap.=sprintf(qq|<%02X> <%04X>\n|,$j,$self->uniByEnc($j));
         }
         $cmap.=qq|endbfchar\n|;
     }
@@ -491,7 +491,7 @@ Returns the character by the given unicode of the fonts encoding map.
 
 =cut
 
-sub encByUni { return( $_[0]->data->{u2c}->{$_[1]} || $_[0]->data->{u2e}->{$_[1]} || 0 ); }
+sub encByUni { return( $_[0]->data->{u2e}->{$_[1]} || $_[0]->data->{u2c}->{$_[1]} || 0 ); }
 
 =item $char = $font->mapByGlyph $glyph
 
@@ -748,6 +748,12 @@ alfred reibenschuh.
 =head1 HISTORY
 
     $Log: BaseFont.pm,v $
+    Revision 2.2  2006/06/14 16:57:52  areibens
+    fixed ToUnicode cmap greneration to use actual encoden rather than the default
+
+    Revision 2.1  2006/06/14 16:53:00  areibens
+    fixed unicode lookup to use actual encoding rather than default
+
     Revision 2.0  2005/11/16 02:16:04  areibens
     revision workaround for SF cvs import not to screw up CPAN
 
